==> jc-1.4.0.tar.gz: gnu/java/rmi/server/ConnectionRunnerPool.h <==
// class gnu.java.rmi.server.ConnectionRunnerPool

// class file dependencies
// @dep_class e2bf2c6ae559b80c gnu_java_rmi_server_ConnectionRunnerPool
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_ConnectionRunnerPool_H_
#define _JC_gnu_java_rmi_server_ConnectionRunnerPool_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object;
struct _jc_gnu_java_rmi_server_UnicastConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_ThreadGroup$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$object	_jc_gnu_java_rmi_server_ConnectionRunnerPool$object;

typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct	_jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24rmi__24server__24ConnectionRunnerPool;
	struct _jc_java_util_ArrayList$object	*freelist;
	struct _jc_java_lang_ThreadGroup$object	*group;
	jint	max__5fsize;
	jint	size;
};
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$object *);

// Static methods
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_ConnectionRunnerPool$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$dispatchConnection$7f673b2e457e5876(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$exit$18a14ad8b1514a1b(_jc_env *);
extern struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *_jc_gnu_java_rmi_server_ConnectionRunnerPool$method$getConnectionRunner$22a0abe4e1dd0f11(_jc_env *);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$setMaxSize$9fd1db4380673758(_jc_env *, jint);
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$setSize$80d4c34703b22d8f(_jc_env *, jint);

// Virtual methods structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods	gnu_java_rmi_server_ConnectionRunnerPool;
};

// Vtype
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$refs {
    _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs	gnu_java_rmi_server_ConnectionRunnerPool;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs	gnu_java_rmi_server_ConnectionRunnerPool;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$object {
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype	*vtype;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype _jc_gnu_java_rmi_server_ConnectionRunnerPool$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_ConnectionRunnerPool, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_ConnectionRunnerPool$class_object;

#endif	/* _JC_gnu_java_rmi_server_ConnectionRunnerPool_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/ConnectionRunnerPool.h <==
// class gnu.java.rmi.server.ConnectionRunnerPool

// class file dependencies
// @dep_class e2bf2c6ae559b80c gnu_java_rmi_server_ConnectionRunnerPool
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_rmi_server_ConnectionRunnerPool_H_
#define _JC_gnu_java_rmi_server_ConnectionRunnerPool_H_

// Forward structure declarations
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object;
struct _jc_gnu_java_rmi_server_UnicastConnection$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_ThreadGroup$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$refs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$refs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs	_jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs;
typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$object	_jc_gnu_java_rmi_server_ConnectionRunnerPool$object;

typedef struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct	_jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable;
typedef const struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype;

// Class fields structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24rmi__24server__24ConnectionRunnerPool;
	struct _jc_java_util_ArrayList$object	*freelist;
	struct _jc_java_lang_ThreadGroup$object	*group;
	jint	max__5fsize;
	jint	size;
};
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool$fields_struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$class_fields;

// Constructors
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_ConnectionRunnerPool$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$dispatchConnection$7f673b2e457e5876(_jc_env *, struct _jc_gnu_java_rmi_server_UnicastConnection$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$exit$18a14ad8b1514a1b(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_rmi_server_ConnectionRunnerPool__24ConnectionRunner$object *_jc_gnu_java_rmi_server_ConnectionRunnerPool$method$getConnectionRunner$22a0abe4e1dd0f11(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$setMaxSize$9fd1db4380673758(_jc_env *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_ConnectionRunnerPool$method$setSize$80d4c34703b22d8f(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods {
};

// Vtable
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vmethods	gnu_java_rmi_server_ConnectionRunnerPool;
};

// Vtype
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$refs {
    _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_refs	gnu_java_rmi_server_ConnectionRunnerPool;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_rmi_server_ConnectionRunnerPool$sub_nonrefs	gnu_java_rmi_server_ConnectionRunnerPool;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_ConnectionRunnerPool$object {
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype	*vtype;
	_jc_gnu_java_rmi_server_ConnectionRunnerPool$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_ConnectionRunnerPool$vtype _jc_gnu_java_rmi_server_ConnectionRunnerPool$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_ConnectionRunnerPool, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_ConnectionRunnerPool$class_object;

#endif	/* _JC_gnu_java_rmi_server_ConnectionRunnerPool_H_ */
